@@ -18,7 +18,6 @@
 #include <KConfigDialog>
 #include <KPluginMetaData>
 #include <QHash>
-#include <QLinkedList>
 #include <QMap>
 #include <QMutex>
 #include <QPointer>
@@ -260,17 +259,17 @@ public:
     qint64 m_docSize;
 
     // viewport stuff
-    QLinkedList<DocumentViewport> m_viewportHistory;
-    QLinkedList<DocumentViewport>::iterator m_viewportIterator;
+    std::list<DocumentViewport> m_viewportHistory;
+    std::list<DocumentViewport>::iterator m_viewportIterator;
     DocumentViewport m_nextDocumentViewport; // see Link::Goto for an explanation
     QString m_nextDocumentDestination;
 
     // observers / requests / allocator stuff
     QSet<DocumentObserver *> m_observers;
-    QLinkedList<PixmapRequest *> m_pixmapRequestsStack;
-    QLinkedList<PixmapRequest *> m_executingPixmapRequests;
+    std::list<PixmapRequest *> m_pixmapRequestsStack;
+    std::list<PixmapRequest *> m_executingPixmapRequests;
     QMutex m_pixmapRequestsMutex;
-    QLinkedList<AllocatedPixmap *> m_allocatedPixmaps;
+    std::list<AllocatedPixmap *> m_allocatedPixmaps;
     qulonglong m_allocatedPixmapsTotalMemory;
     QList<int> m_allocatedTextPagesFifo;
     int m_maxAllocatedTextPages;
