@@ -105,6 +105,9 @@ public:
     bool shiftModifier() const;
     void setShiftModifier(bool shiftModifier);
 
+    bool willCommit() const;
+    void setWillCommit(bool willCommit);
+
     static std::shared_ptr<Event> createFormCalculateEvent(FormField *target, Page *targetPage, FormField *source = nullptr, Page *sourcePage = nullptr, const QString &targetName = QString());
     static std::shared_ptr<Event> createFormatEvent(FormField *target, Page *targetPage, const QString &targetName = QString());
     static std::shared_ptr<Event> createKeystrokeEvent(FormField *target, Page *targetPage);
