@@ -280,7 +280,7 @@ static void setSharedAnnotationPropertiesToPopplerAnnotation(const Okular::Annot
     popplerAnnotation->setModificationDate(okularAnnotation->modificationDate());
 }
 
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
 static void setPopplerStampAnnotationCustomImage(const Poppler::Page *page, Poppler::StampAnnotation *pStampAnnotation, const Okular::StampAnnotation *oStampAnnotation)
 {
     const QSize size = page->pageSize();
@@ -307,7 +307,7 @@ static void updatePopplerAnnotationFromOkularAnnotation(const Okular::TextAnnota
 static void updatePopplerAnnotationFromOkularAnnotation(const Okular::LineAnnotation *oLineAnnotation, Poppler::LineAnnotation *pLineAnnotation)
 {
     QLinkedList<QPointF> points;
-    const QLinkedList<Okular::NormalizedPoint> annotPoints = oLineAnnotation->linePoints();
+    const QList<Okular::NormalizedPoint> annotPoints = oLineAnnotation->linePoints();
     for (const Okular::NormalizedPoint &p : annotPoints) {
         points.append(normPointToPointF(p));
     }
@@ -348,7 +348,7 @@ static void updatePopplerAnnotationFromOkularAnnotation(const Okular::HighlightA
     pHighlightAnnotation->setHighlightQuads(pQuads);
 }
 
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
 static void updatePopplerAnnotationFromOkularAnnotation(const Okular::StampAnnotation *oStampAnnotation, Poppler::StampAnnotation *pStampAnnotation, const Poppler::Page *page)
 {
     setPopplerStampAnnotationCustomImage(page, pStampAnnotation, oStampAnnotation);
@@ -363,8 +363,8 @@ static void updatePopplerAnnotationFromOkularAnnotation(const Okular::StampAnnot
 static void updatePopplerAnnotationFromOkularAnnotation(const Okular::InkAnnotation *oInkAnnotation, Poppler::InkAnnotation *pInkAnnotation)
 {
     QList<QLinkedList<QPointF>> paths;
-    const QList<QLinkedList<Okular::NormalizedPoint>> inkPathsList = oInkAnnotation->inkPaths();
-    for (const QLinkedList<Okular::NormalizedPoint> &path : inkPathsList) {
+    const QList<QList<Okular::NormalizedPoint>> inkPathsList = oInkAnnotation->inkPaths();
+    for (const QList<Okular::NormalizedPoint> &path : inkPathsList) {
         QLinkedList<QPointF> points;
         for (const Okular::NormalizedPoint &p : path) {
             points.append(normPointToPointF(p));
@@ -420,7 +420,7 @@ static Poppler::Annotation *createPopplerAnnotationFromOkularAnnotation(const Ok
     return pHighlightAnnotation;
 }
 
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
 static Poppler::Annotation *createPopplerAnnotationFromOkularAnnotation(const Okular::StampAnnotation *oStampAnnotation, Poppler::Page *page)
 {
     Poppler::StampAnnotation *pStampAnnotation = new Poppler::StampAnnotation();
@@ -483,7 +483,7 @@ void PopplerAnnotationProxy::notifyAddition(Okular::Annotation *okl_ann, int pag
         ppl_ann = createPopplerAnnotationFromOkularAnnotation(static_cast<Okular::HighlightAnnotation *>(okl_ann));
         break;
     case Okular::Annotation::AStamp:
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
     {
         bool wasDenyWriteEnabled = okl_ann->flags() & Okular::Annotation::DenyWrite;
 
@@ -516,7 +516,7 @@ void PopplerAnnotationProxy::notifyAddition(Okular::Annotation *okl_ann, int pag
         return;
     }
 
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
     okl_ann->setFlags(okl_ann->flags() | Okular::Annotation::ExternallyDrawn);
 #else
     // Poppler doesn't render StampAnnotations yet
@@ -595,7 +595,7 @@ void PopplerAnnotationProxy::notifyModification(const Okular::Annotation *okl_an
     case Poppler::Annotation::AStamp: {
         const Okular::StampAnnotation *okl_stampann = static_cast<const Okular::StampAnnotation *>(okl_ann);
         Poppler::StampAnnotation *ppl_stampann = static_cast<Poppler::StampAnnotation *>(ppl_ann);
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
         Poppler::Page *ppl_page = ppl_doc->page(page);
         updatePopplerAnnotationFromOkularAnnotation(okl_stampann, ppl_stampann, ppl_page);
         delete ppl_page;
@@ -630,9 +630,9 @@ void PopplerAnnotationProxy::notifyRemoval(Okular::Annotation *okl_ann, int page
 
     Poppler::Page *ppl_page = ppl_doc->page(page);
     annotationsOnOpenHash->remove(okl_ann);
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
     if (okl_ann->subType() == Okular::Annotation::AStamp) {
-        deletedStampsAnnotationAppearance[static_cast<Okular::StampAnnotation *>(okl_ann)] = std::move(ppl_ann->annotationAppearance());
+        deletedStampsAnnotationAppearance[static_cast<Okular::StampAnnotation *>(okl_ann)] = ppl_ann->annotationAppearance();
     }
 #endif
     ppl_page->removeAnnotation(ppl_ann); // Also destroys ppl_ann
@@ -876,7 +876,7 @@ static Okular::Annotation *createAnnotationFromPopplerAnnotation(const Poppler::
     oLineAnn->setShowCaption(popplerAnnotation->lineShowCaption());
     oLineAnn->setLineIntent(popplerToOkular(popplerAnnotation->lineIntent()));
 
-    QLinkedList<Okular::NormalizedPoint> points;
+    QList<Okular::NormalizedPoint> points;
     const QLinkedList<QPointF> popplerPoints = popplerAnnotation->linePoints();
     for (const QPointF &p : popplerPoints) {
         points << Okular::NormalizedPoint(p.x(), p.y());
@@ -928,9 +928,9 @@ static Okular::Annotation *createAnnotationFromPopplerAnnotation(const Poppler::
     Okular::InkAnnotation *oInkAnn = new Okular::InkAnnotation();
 
     const QList<QLinkedList<QPointF>> popplerInkPaths = popplerAnnotation->inkPaths();
-    QList<QLinkedList<Okular::NormalizedPoint>> okularInkPaths;
+    QList<QList<Okular::NormalizedPoint>> okularInkPaths;
     for (const QLinkedList<QPointF> &popplerInkPath : popplerInkPaths) {
-        QLinkedList<Okular::NormalizedPoint> okularInkPath;
+        QList<Okular::NormalizedPoint> okularInkPath;
         for (const QPointF &popplerPoint : popplerInkPath) {
             okularInkPath << Okular::NormalizedPoint(popplerPoint.x(), popplerPoint.y());
         }
@@ -1070,7 +1070,7 @@ Okular::Annotation *createAnnotationFromPopplerAnnotation(Poppler::Annotation *p
         break;
     }
     case Poppler::Annotation::AStamp:
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
         externallyDrawn = true;
 #endif
         tieToOkularAnn = true;
@@ -1097,7 +1097,7 @@ Okular::Annotation *createAnnotationFromPopplerAnnotation(Poppler::Annotation *p
         if (externallyDrawn) {
             okularAnnotation->setFlags(okularAnnotation->flags() | Okular::Annotation::ExternallyDrawn);
         }
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
         if (okularAnnotation->subType() == Okular::Annotation::SubType::AStamp) {
             Okular::StampAnnotation *oStampAnn = static_cast<Okular::StampAnnotation *>(okularAnnotation);
             Poppler::StampAnnotation *pStampAnn = static_cast<Poppler::StampAnnotation *>(popplerAnnotation);
@@ -1143,7 +1143,7 @@ Okular::Annotation *createAnnotationFromPopplerAnnotation(Poppler::Annotation *p
         okularWindow.setSummary(popplerPopup.summary());
 
         // Convert the poppler revisions to Okular revisions
-        QLinkedList<Okular::Annotation::Revision> &okularRevisions = okularAnnotation->revisions();
+        QList<Okular::Annotation::Revision> &okularRevisions = okularAnnotation->revisions();
         const QList<Poppler::Annotation *> popplerRevisions = popplerAnnotation->revisions();
         for (Poppler::Annotation *popplerRevision : popplerRevisions) {
             bool deletePopplerRevision;
